@@ -29,6 +29,8 @@ use constant {
 
 	# Internal
     ERROR_PREFIX => 'Getopt::ArgParse: ',
+    PRINT_REQUIRED => 1,
+    PRINT_OPTIONAL => 2,
 };
 
 # Allow customization
@@ -53,7 +55,7 @@ my %Type2ConstMap = (
 
 
 sub _croak {
-    die join('', @_);
+    die join('', @_, "\n");
 }
 
 # Program name. Default $0
@@ -201,7 +203,7 @@ sub add_subparsers {
 
     my $args = { @_ };
 
-    my $title       = (delete $args->{title} || 'Subcommands') . ':';
+    my $title       = (delete $args->{title} || 'subcommands') . ':';
     my $description = delete $args->{description} || '';
 
     _croak $self->error_prefix . sprintf(
@@ -1005,7 +1007,10 @@ sub format_usage {
     my $aliases = $self->aliases;
     my $prog = $self->prog;
     $prog .= ' (' . join(', ', @$aliases) . ')' if @$aliases;
+    if( $self->help ) {
     push @usage, wrap('', '', $prog. ': ' . $self->help);
+        push @usage, '';
+    }
 
     my ($help, $option_string) =  $self->_format_group_usage();
     $Text::Wrap::columns = 80;
@@ -1039,8 +1044,6 @@ sub format_usage {
         }
     }
 
-    push @usage, '';
-
     push @usage, @$help;
 
     if (exists $self->{-subparsers}) {
@@ -1055,16 +1058,14 @@ sub format_usage {
             $max = $len if $len > $max;
         }
 
-        $max *= -1;
-
         for my $command ( sort keys  %{$self->{-subparsers}{-parsers}} ) {
             my $parser = $self->{-subparsers}{-parsers}{$command};
-            my $tab_head = ' ' x ( -1 * $max + 2 );
+            my $tab_head = ' ' x ( $max + 2 );
 
             my @desc = split("\n", wrap('', '', $parser->help));
             my $desc = (shift @desc) || '';
             $_ = $tab_head . $_ for @desc;
-            push @usage, sprintf("  %${max}s %s", $command, join("\n", $desc, @desc));
+            push @usage, sprintf("  %-${max}s    %s", $command, join("\n", $desc, @desc));
         }
     }
 
@@ -1146,14 +1147,20 @@ sub _format_group_usage {
         push @usage, wrap('', '', $group . ': ' . ($self->{-group_description}{$group} || '')  );
     }
 
-    if (@position_specs) {
-        push @usage, 'positional arguments:';
-        push @usage, @{ $self->_format_usage_by_spec(\@position_specs) };
-    }
-
-    if (@option_specs) {
-        push @usage, 'optional arguments:';
-        push @usage, @{ $self->_format_usage_by_spec(\@option_specs) };
+    # named arguments are arguments preceded by a hyphen as optional
+    # vs. positional are too confusing.
+    for my $spec_name ( [ \@position_specs, 'positional' ], [ \@option_specs, 'named' ]) {
+        my ($specs, $spec_name) = @$spec_name;
+        for my $type_name ( [ PRINT_REQUIRED, 'required'], [ PRINT_OPTIONAL, 'optional'] ) {
+            my ($type, $type_name) = @$type_name;
+            my $output = $self->_format_usage_by_spec($specs, $type);
+            if (@$output) {
+                push @usage, '';
+                # Start a section: e.g. required positional arguments:
+                push @usage, sprintf('%s %s arguments:', $type_name, $spec_name);
+                push @usage, @$output;
+            }
+        }
     }
 
     $Text::Wrap::columns = $old_wrap_columns; # restore to original
@@ -1162,8 +1169,9 @@ sub _format_group_usage {
 }
 
 sub _format_usage_by_spec {
-    my $self = shift;
-    my $specs = shift;
+    my $self       = shift;
+    my $specs      = shift;
+    my $print_type = shift;
 
     return unless $specs;
 
@@ -1171,12 +1179,19 @@ sub _format_usage_by_spec {
     my $max = 10;
     my @item_help;
 
-    for my $spec ( @$specs ) {
-        my $item = sprintf(
-            "%s %s",
-            join(', ',  @{$spec->{flags}}),
-            $spec->{metavar},
-        );
+  SPEC: for my $spec ( @$specs ) {
+        next SPEC if    ($print_type == PRINT_OPTIONAL &&  $spec->{'required'})
+                     || ($print_type == PRINT_REQUIRED && !$spec->{'required'});
+
+        my $item = $spec->{metavar};
+
+        if (@{$spec->{flags}}) {
+            $item = sprintf(
+                "%s %s",
+                join(', ',  @{$spec->{flags}}),
+                $spec->{metavar},
+            );
+        }
         my $len = length($item);
         $max = $len if $len > $max;
 
@@ -1189,7 +1204,7 @@ sub _format_usage_by_spec {
                 while (my ($k, $v) = each %{$spec->{default}}) {
                     push @$values, "$k=$v";
                 }
-            } elsif (ref $spec->{default} eq "ARRAY") {
+            } elsif (ref $spec->{default} eq 'ARRAY') {
                 $values = $spec->{default};
             } else {
                 $values = [ $spec->{default} ];
@@ -1226,14 +1241,13 @@ sub _format_usage_by_spec {
         ];
     }
 
-    $max *= -1;
-    my $format = "    %${max}s    %s %s";
+    my $format = "  %-${max}s    %s %s";
     $Text::Wrap::columns = 60;
     for my $ih (@item_help) {
         my $item_len = length($ih->[0]);
         # The prefixed whitespace in subsequent lines in the wrapped
         # help string
-        my $sub_tab = " " x (-1 * $max + 4 + 4 + 2);
+        my $sub_tab = " " x ($max + 4 + 4 + 2);
         my @help = split("\n", wrap('', '', $ih->[2]));
 
         my $help = (shift @help) || '' ;      # head
@@ -1299,7 +1313,7 @@ Mytram <mytram2@gmail.com> (original author)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Mytram.
+This software is Copyright (c) 2015 by Mytram.
 
 This is free software, licensed under:
 
